@@ -202,13 +202,13 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 
 			if (i + priv->size < len) {
                                 /* read data in one block */
-				memcpy ((void*) ((int)(priv->exif_chunk) + priv->bytes_read), (void*)&buf[i], priv->size); 
+				memcpy (priv->exif_chunk + priv->bytes_read, &buf[i], priv->size); 
 				priv->state = EMR_READ;
 				i = i + priv->size - 1; /* the for-loop consumes the other byte */
 			}
 			else {
 				int chunk_len = len - i;
-				memcpy ((void*)((int)priv->exif_chunk + priv->bytes_read), (void*)&buf[i], chunk_len);
+				memcpy (priv->exif_chunk + priv->bytes_read, &buf[i], chunk_len);
 				priv->bytes_read += chunk_len; /* bytes already read */
 				priv->size = (i + priv->size) - len; /* remaining data to read */
 				i = len - 1;
@@ -228,12 +228,12 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 
 			if (i + priv->size < len) {
                                 /* read data in one block */
-				memcpy ((void*)((int)priv->iptc_chunk + priv->bytes_read), (void*)&buf[i], priv->size); 
+				memcpy (priv->iptc_chunk + priv->bytes_read, &buf[i], priv->size); 
 				priv->state = EMR_READ;
 			}
 			else {
 				int chunk_len = len - i;
-				memcpy ((void*)((int)priv->iptc_chunk + priv->bytes_read), (void*)&buf[i], chunk_len);
+				memcpy (priv->iptc_chunk + priv->bytes_read, &buf[i], chunk_len);
 				priv->bytes_read += chunk_len; /* bytes already read */
 				priv->size = (i + priv->size) - len; /* remaining data to read */
 				i = len - 1;
