@@ -18,7 +18,7 @@
 
 /* Maximum zoom factor */
 #define MAX_ZOOM_FACTOR 20
-#define MIN_ZOOM_FACTOR 0.01
+#define MIN_ZOOM_FACTOR 0.02
 
 #define CHECK_MEDIUM 8
 #define CHECK_BLACK 0x00000000
@@ -45,7 +45,7 @@ typedef enum {
 typedef enum {
 	PROGRESSIVE_NONE,	/* We are not loading an image or it is already loaded */
 	PROGRESSIVE_LOADING,	/* An image is being loaded */
-	PROGRESSIVE_POLISHING,	/* We have finished loading an image but have not scaled it with interpolation */
+	PROGRESSIVE_POLISHING	/* We have finished loading an image but have not scaled it with interpolation */
 } ProgressiveState;
 
 /* Signal IDs */
@@ -474,8 +474,14 @@ paint_rectangle (EogScrollView *view, ArtIRect *rect, GdkInterpType interp_type)
 
 	priv = view->priv;
 
+	if (!GTK_WIDGET_DRAWABLE (priv->display))
+		return;
+
 	compute_scaled_size (view, priv->zoom, &scaled_width, &scaled_height);
 
+	if (scaled_width <= 1 || scaled_height <= 1)
+		return;
+
 	width = GTK_WIDGET (priv->display)->allocation.width;
 	height = GTK_WIDGET (priv->display)->allocation.height;
 
@@ -960,8 +966,8 @@ set_zoom (EogScrollView *view, double zoom,
 				     &xofs, &yofs);
 
 	/* set new values */
-	priv->xofs = xofs; // (img_width * x_rel * zoom) - anchorx;
-	priv->yofs = yofs; // (img_height * y_rel * zoom) - anchory;
+	priv->xofs = xofs; /* (img_width * x_rel * zoom) - anchorx; */
+	priv->yofs = yofs; /* (img_height * y_rel * zoom) - anchory; */
 #if 0
 	g_print ("xofs: %i  yofs: %i\n", priv->xofs, priv->yofs);
 #endif
@@ -1003,6 +1009,11 @@ set_zoom_fit (EogScrollView *view)
 				   gdk_pixbuf_get_height (priv->pixbuf),
 				   priv->upscale);
 
+	if (new_zoom > MAX_ZOOM_FACTOR)
+		new_zoom = MAX_ZOOM_FACTOR;
+	else if (new_zoom < MIN_ZOOM_FACTOR)
+		new_zoom = MIN_ZOOM_FACTOR;
+
 	if (DOUBLE_EQUAL (new_zoom, priv->zoom))
 		return;
 
@@ -1287,7 +1298,9 @@ display_map_event (GtkWidget *widget, GdkEvent *event, gpointer data)
 	view = EOG_SCROLL_VIEW (data);
 	priv = view->priv;
 
+#ifdef DEBUG
 	g_print ("display_map_event ...\n");
+#endif
 
 	set_zoom_fit (view);
 	check_scrollbar_visibility (view, NULL);
@@ -1803,7 +1816,7 @@ eog_scroll_view_dispose (GObject *object)
 
 	view = EOG_SCROLL_VIEW (object);
 	priv = view->priv;
-
+	
 	if (priv->uta != NULL) {
 		art_uta_free (priv->uta);
 		priv->uta = NULL;
