@@ -36,11 +36,16 @@ static void
 load_uri_with_role (const char *uri, const char *role)
 {
 	GtkWidget *window;
+	GError *error = NULL;
 
-	window = eog_window_new ();
+	window = eog_window_new (&error);
+
+	if (error != NULL) {
+		gtk_main_quit ();
+	}
 
 	if (strlen (uri) != 0)
-		eog_window_open (EOG_WINDOW (window), uri);
+		eog_window_open (EOG_WINDOW (window), EOG_VIEWER_CONTROL_IID, uri, NULL);
 
 	gtk_window_set_role (GTK_WINDOW (window), role);
 	gtk_widget_show (window);
